@@ -1,68 +1,3 @@
-readme_template = '''# New BigFlow project
-
-## Requirements & preparations
-
-Follow the instructions in 
-[Preparations](https://github.com/allegro/bigflow/blob/master/docs/scaffold.md#preparation).
-
-    
-## Example worklfows
-
-There are two example workflows here: **internationalports** and  **wordcount**.
-The first one is based only on BigQuery and the second one uses Beam (Dataflow).
-
-Run them and check the results.
-
-1. The results of `internationalports` are saved in BigQuery under the `bigflow_test` dataset
-   in the `ports` and `more_ports` tables.
-
-1. The results of `wordcount` are saved in the `PROJECT_ID_PLACEHOLDER` folder
-   in the `beam_runner/temp` Storage bucket used by Dataflow.
-
-
-## Running locally
-To run a workflow, type in command line (in a project directory): 
-
-```  
-bigflow run --workflow internationalports
-```
-
-or
-
-```  
-bigflow run --workflow wordcount
-```
-
-See [Running workflows](https://github.com/allegro/bigflow/blob/master/docs/cli.md#running-workflows)
-cheat sheet.    
-  
-  
-## Building & deploying
-  
-Build the project:
-
-```java
-bigflow build
-```
-
-Deploy it:
-    
-```
-bigflow deploy
-```   
-
-See [Building](https://github.com/allegro/bigflow/blob/master/docs/cli.md#building-airflow-dags) 
-and [Deploying](https://github.com/allegro/bigflow/blob/master/docs/cli.md#deploying-to-gcp) 
-cheat sheet.  
-'''
-
-docker_template = '''FROM python:3.7
-COPY ./dist /dist
-RUN apt-get -y update && apt-get install -y libzbar-dev libc-dev musl-dev
-RUN pip install pip==20.2.4
-RUN for i in /dist/*.whl; do pip install $i --use-feature=2020-resolver; done
-'''
-
 basic_deployment_config_template = '''from bigflow.configuration import DeploymentConfig
 
 deployment_config = DeploymentConfig(
@@ -80,7 +15,6 @@ advanced_deployment_config_template = '''.add_configuration(
                                 'dags_bucket': '{dags_bucket}',
                             }})
 '''
-requirements_template = '''bigflow[bigquery,log,dataproc,dataflow]=={bigflow_version}'''
 
 project_setup_template = '''from bigflow.build import default_project_setup
 
@@ -94,7 +28,7 @@ beam_pipeline_template = '''import uuid
 import logging
 
 from bigflow.configuration import Config
-from bigflow.resources import find_or_create_setup_for_main_project_package, resolve, get_resource_absolute_path
+from bigflow.resources import find_or_create_setup_for_main_project_package, get_resource_absolute_path
 from apache_beam.options.pipeline_options import SetupOptions, StandardOptions, WorkerOptions, GoogleCloudOptions, \
     PipelineOptions
 
@@ -127,8 +61,8 @@ def dataflow_pipeline_options():
 
     setup_file_path = find_or_create_setup_for_main_project_package()
     requirements_file_path = get_resource_absolute_path('requirements.txt')
-    options.view_as(SetupOptions).setup_file = resolve(setup_file_path)
-    options.view_as(SetupOptions).requirements_file = resolve(requirements_file_path)
+    options.view_as(SetupOptions).setup_file = str(setup_file_path)
+    options.view_as(SetupOptions).requirements_file = str(requirements_file_path)
 
     logger.info(f"Run beam pipeline with options {str(options)}")
     return options'''
@@ -223,7 +157,7 @@ select_polish_ports = dataset.write_truncate('ports', '''
 
 populate_ports_table = dataset.collect('''
         INSERT INTO `{ports}` (port_name, port_latitude, port_longitude, country, index_number)
-        VALUES 
+        VALUES
         ('GDYNIA', 54.533333, 18.55, 'POL', '28740'),
         ('GDANSK', 54.35, 18.666667, 'POL', '28710'),
         ('SANKT-PETERBURG', 59.933333, 30.3, 'RUS', '28370'),
@@ -281,135 +215,3 @@ class FakeFile(object):
     data = {{}}
 
 '''
-
-gitignore_template = '''# Byte-compiled / optimized / DLL files
-__pycache__/
-*.py[cod]
-*$py.class
-
-# C extensions
-*.so
-
-# Distribution / packaging
-.Python
-build/
-develop-eggs/
-dist/
-downloads/
-eggs/
-.eggs/
-lib/
-lib64/
-parts/
-sdist/
-var/
-wheels/
-pip-wheel-metadata/
-share/python-wheels/
-*.egg-info/
-.installed.cfg
-*.egg
-MANIFEST
-
-# PyInstaller
-#  Usually these files are written by a python script from a template
-#  before PyInstaller builds the exe, so as to inject date/other infos into it.
-*.manifest
-*.spec
-
-# Installer logs
-pip-log.txt
-pip-delete-this-directory.txt
-
-# Unit test / coverage reports
-htmlcov/
-.tox/
-.nox/
-.coverage
-.coverage.*
-.cache
-nosetests.xml
-coverage.xml
-*.cover
-.hypothesis/
-.pytest_cache/
-
-# Translations
-*.mo
-*.pot
-
-# Django stuff:
-*.log
-local_settings.py
-db.sqlite3
-db.sqlite3-journal
-
-# Flask stuff:
-instance/
-.webassets-cache
-
-# Scrapy stuff:
-.scrapy
-
-# Sphinx documentation
-docs/_build/
-
-# PyBuilder
-target/
-
-# Jupyter Notebook
-.ipynb_checkpoints
-
-# IPython
-profile_default/
-ipython_config.py
-
-# pyenv
-.python-version
-
-# pipenv
-#   According to pypa/pipenv#598, it is recommended to include Pipfile.lock in version control.
-#   However, in case of collaboration, if having platform-specific dependencies or dependencies
-#   having no cross-platform support, pipenv may install dependencies that don't work, or not
-#   install all needed dependencies.
-#Pipfile.lock
-
-# celery beat schedule file
-celerybeat-schedule
-
-# SageMath parsed files
-*.sage.py
-
-# Environments
-.env
-.venv
-.venv2
-env/
-venv/
-ENV/
-env.bak/
-venv.bak/
-
-# Spyder project settings
-.spyderproject
-.spyproject
-
-# Rope project settings
-.ropeproject
-
-# mkdocs documentation
-/site
-
-# mypy
-.mypy_cache/
-.dmypy.json
-dmypy.json
-
-# Pyre type checker
-.pyre/
-
-# BigFlow deployment artifacts
-/.dags/
-/.image/
-.idea'''
-
